from django.db import models
from django.contrib.auth.models import User

# Create your models here.
class Cooker(models.Model):
	m_user = models.OneToOneField(User,on_delete=models.CASCADE,blank=True,null=True)
	m_photo = models.FileField(blank=True,null=True)
	m_resto = models.CharField(max_length=64,blank=True,null=True)
	m_phone = models.CharField(max_length=64,blank=True,null=True)
	m_whats = models.CharField(max_length=64,blank=True,null=True)
	m_face = models.CharField(max_length=64,blank=True,null=True)
	m_twit = models.CharField(max_length=64,blank=True,null=True)
	m_contacts = models.TextField(blank=True,null=True)
	m_token = models.IntegerField(blank=True,null=True)
	def recettes(self):
		return Recette.objects.filter(m_meal__id = self.id)
	def nb_recettes(self):
		return Recette.objects.filter(m_cuisto__id = self.id).count()

class Menu(models.Model):
	m_logo = models.FileField(blank=True,null=True)
	m_name = models.CharField(max_length=64,blank=True,null=True)
	m_description = models.TextField(blank=True,null=True)

class Meal(models.Model):
	m_name = models.CharField(max_length=64,blank=True,null=True)
	m_name_plus = models.CharField(max_length=64,blank=True,null=True)
	m_description = models.CharField(max_length=256,blank=True,null=True)
	m_picture = models.FileField(blank=True,null=True)
	m_picture_hype = models.FileField(blank=True,null=True)
	m_date_add = models.DateTimeField(blank=True,null=True,auto_now=True)
	def __str__(self):
		return self.m_name
	def recettes(self):
		return Recette.objects.filter(m_meal__id = self.id)
	def nb_recettes(self):
		return Recette.objects.filter(m_meal__id = self.id).count()
	class Meta:
		ordering=('-m_date_add',)
			
class Resto(models.Model):
	m_name = models.CharField(max_length=64,blank=True,null=True)
	m_description = models.CharField(max_length=256,blank=True,null=True)	
	m_localisation = models.CharField(max_length=64,blank=True,null=True)
	m_gmap = models.FileField(blank=True,null=True)
	m_phones = models.TextField(blank=True,null=True)
	m_picture = models.FileField(blank=True,null=True)
	m_mail = models.TextField(blank=True,null=True)  

	is_active = models.BooleanField(blank=True,null=True)

	def __str__(self):
		return self.m_name

class Recette(models.Model):
	m_name = models.CharField(max_length=64,blank=True,null=True)#unique=True
	m_description = models.TextField(blank=True,null=True)
	m_picture = models.FileField(blank=True,null=True)
	m_difficulty = models.CharField(choices = [
		('Très Facile', 'Très Facile'), ('Facile', 'Facile'), ('Moyen', 'Moyen'), ('Difficile', 'Difficile'), ('Très Difficile','Très Difficile')
	], default = 'Facile', blank = True, null = True,max_length=64) #0:Easy, 1:Moyen 2:Difficile
	m_stars = models.IntegerField(blank=True,null=True) #6 Premium
	m_content = models.TextField(blank=True,null=True)
	m_preparation = models.IntegerField(blank=True,null=True,default=0)
	m_cuisson = models.IntegerField(blank=True,null=True,default=0)
	m_category = models.IntegerField(choices = [
		(1, 'Boisson'), (2, 'Déssert'), (3, 'Féculent'), (4, 'Fruit de Mer'), (5,'Légume'), (6,'Patisserie'), (7,'Viande')
	], blank=True,null=True)
	m_cuisto = models.ForeignKey(Cooker,on_delete=models.CASCADE,blank=True,null=True)
	m_meal = models.ForeignKey(Meal,on_delete=models.CASCADE,blank=True,null=True)
	m_date_added = models.DateTimeField(auto_now=True)
	m_viewers = models.SlugField(blank=True,null=True)
	m_required_num = models.IntegerField(blank=True,null=True)

	m_dariq = models.FloatField(blank=True,null=True,default=4)
	m_youtube_link = models.CharField(max_length=256,blank=True,null=True) 
	def price(self):
		result = 125
		if self.m_stars == 4:
			result *= 4
		elif self.m_stars == 5:
			result *= 8
		elif self.m_stars == 6:
			result *= 20	
		return result

	def category(self):
		result = "Aucune"
		cats = ["Aucune","Boisson","Déssert","Féculent","Fruit de Mer","Légumes","Patisserie","Viande"]
		if self.m_category != None:
			result = cats[self.m_category]
		return result

	def hour_calc(self,tim):
		if tim == None:
			tim = 0
		hours = int(tim/60)
		minutes = int(tim%60)
		if hours == 0:
			hours = ""
		else:
			hours = str(hours)+"h "
		if minutes == 0:
			minutes = ""
		else:
			minutes = str(minutes)+"min "
		message =  hours+minutes
		return message

	def __str__(self):
		return self.m_name

	def status(self):
		result = list()
		if self.m_stars != None :
			result = range(self.m_stars)
		return result

	def time_prepa(self):
		return self.hour_calc(self.m_preparation)

	def time_cuisson(self):
		return self.hour_calc(self.m_cuisson)

	def time_total(self):
		result = 0
		if self.m_preparation != None:
			result += self.m_preparation
		if self.m_cuisson:
			result += self.m_cuisson
		return self.hour_calc(result)

	def get_ingredients(self):
		return IngredientRecette.objects.filter(m_recette__id = self.id)

	class Meta:
		ordering=('m_name',)

class Proposal(models.Model):
	m_name = models.CharField(max_length=64,blank=True,null=True)#unique=True
	m_description = models.CharField(max_length=256,blank=True,null=True)
	m_picture = models.FileField(blank=True,null=True)
	m_difficulty = models.CharField(choices = [
		('Très Facile', 'Très Facile'), ('Facile', 'Facile'), ('Moyen', 'Moyen'), ('Difficile', 'Difficile'), ('Très Difficile','Très Difficile')
	], default = 'Facile', blank = True, null = True,max_length=64) #0:Easy, 1:Moyen 2:Difficile
	m_content = models.TextField(blank=True,null=True)
	m_preparation = models.IntegerField(blank=True,null=True,default=0)
	m_cuisson = models.IntegerField(blank=True,null=True,default=0)
	m_category = models.IntegerField(choices = [
		(1, 'Boisson'), (2, 'Déssert'), (3, 'Féculent'), (4, 'Fruit de Mer'), (5,'Légume'), (6,'Patisserie'), (7,'Viande')
	], blank=True,null=True)
	m_cuisto = models.ForeignKey(Cooker,on_delete=models.CASCADE,blank=True,null=True)
	m_meal = models.ForeignKey(Meal,on_delete=models.CASCADE,blank=True,null=True)
	m_date_added = models.DateTimeField(auto_now=True)
	m_required_num = models.IntegerField(blank=True,null=True)
	m_token = models.ForeignKey(User,on_delete=models.CASCADE,blank=True,null=True)
	m_recette_dariq = models.IntegerField(blank=True,null=True)
	m_youtube_link = models.CharField(max_length=256,blank=True,null=True)
	m_ingredients_list = models.TextField(blank=True,null=True)

class Ingredient(models.Model):
	m_picture = models.FileField(blank=True,null=True)
	m_name = models.CharField(max_length=256,blank=True,null=True)#unique=True
	def __str__(self):
		return self.m_name

	class Meta:
		ordering=('m_name',)

class IngredientRecette(models.Model):
	m_recette = models.ForeignKey(Recette,on_delete=models.CASCADE,blank=True,null=True)
	m_ingredient = models.ForeignKey(Ingredient,on_delete=models.CASCADE,blank=True,null=True)
	m_quantite = models.IntegerField(blank=True,null=True,default=None)
	m_unite = models.CharField(max_length=256,blank=True,null=True,default=" ")
	m_precision = models.TextField(blank=True,null=True,default="#")
	def __str__(self):
		return str(self.m_recette)+" : "+str(self.m_ingredient)

class Commentaire(models.Model):
	"""docstring for Commentaire"""
	m_message = models.TextField(blank=True,null=True)
	m_author = models.CharField(max_length=64,blank=True,null=True)
	m_user_token = models.IntegerField(blank=True,null=True)
	m_role = models.CharField(max_length=64,blank=True,null=True)
	m_date = models.DateTimeField(auto_now=True,blank=True,null=True)
	m_value_id = models.IntegerField(blank=True,null=True)
	m_reply = models.IntegerField(blank=True,null=True,default=0)
	
	m_recette = models.ForeignKey(Recette,on_delete=models.CASCADE,blank=True,null=True)
	def __str__(self):
		return self.m_message

	def nb_rep(self):
		return 0

class RecetteDetail(models.Model):
	m_recette = models.ForeignKey(Recette,on_delete=models.CASCADE,blank=True,null=True)
	m_user_token = models.IntegerField(blank=True,null=True)
	m_sens = models.IntegerField(blank=True,null=True)
	m_description = models.TextField(blank=True,null=True)
	m_date = models.DateTimeField(auto_now=True,blank=True,null=True)

class FoodDariq(models.Model):
	m_montant=models.FloatField(blank=True,null=True)
	m_food = models.ForeignKey(Recette,on_delete=models.CASCADE,blank=True,null=True)
	m_user_token=models.IntegerField(blank=True,null=True)
	m_date = models.DateTimeField(auto_now=True,blank=True,null=True)

class Customer_Delivery(models.Model):
	m_user = models.OneToOneField(User,on_delete=models.CASCADE,blank=True,null=True)
	m_tel = models.CharField(max_length=256,blank=True,null=True,default=" ")
	m_mail = models.CharField(max_length=256,blank=True,null=True,default=" ")

class Detail_Delivery(models.Model):
	m_food= models.ForeignKey(Recette,on_delete=models.CASCADE,blank=True,null=True)
	m_quantite = models.IntegerField(blank=True,null=True)
	m_date= models.DateTimeField(auto_now=True,blank=True,null=True)

class Full_Delivey(models.Model):
	m_details = models.ForeignKey(Detail_Delivery,on_delete=models.CASCADE,blank=True,null=True)
	m_customer = models.ForeignKey(Customer_Delivery,on_delete=models.CASCADE,blank=True,null=True) 
	m_date = models.DateTimeField(auto_now=True,blank=True,null=True)
	m_status = models.IntegerField(blank=True,null=True)
