from django.http import FileResponse, HttpResponse, HttpResponseRedirect, JsonResponse
from django.shortcuts import render,redirect,get_object_or_404
from django.core.paginator import Paginator
from django.contrib.auth import authenticate, login, logout
from .models import *
import os
# Create your views here.
def basis(request):
	resto = Resto.objects.first()
	context = dict()
	context["resto"] = resto
	return context

def search(request):
	recettes_query = Recette.objects.filter(m_name__contains=request.POST["name"])
	template = "food/search.html"
	paginator = Paginator(recettes_query,12)
	page_number = request.GET.get('page') 
	pages = paginator.get_page(page_number)
	context = {
		'link':1,
		'pages':pages,
		'search':request.POST["name"],
		'num_pages':paginator.num_pages,
		'page_range':paginator.page_range
	}
	context.update(basis(request))
	return render(request,template,context)		

def index(request):
	template = "food/index.html"
	banners = Meal.objects.filter()[:5]
	some_recs = list()
	for rec in Recette.objects.filter(m_stars=6)[:2]:
		some_recs.append(rec)
	for rec in Recette.objects.exclude(m_stars=6)[:5]:
		some_recs.append(rec)
	cuistos = Cooker.objects.filter()[:4]
	comments = Commentaire.objects.filter()[:6]
	context = {
		'link':0,
		'banners':banners,
		'cuistos':cuistos,
		'some_recs':some_recs[:5],
		'comments':comments
	}
	context.update(basis(request))
	return render(request,template,context)

def deliveries(request):
	template = "food/deliveries.html"
	banners = [Meal.objects.last()]
	banners2 = Meal.objects.filter()[:6]
	recettes = Recette.objects.filter()[:14]

	paginator = Paginator(recettes,6)
	page_number = request.GET.get('page') 
	pages = paginator.get_page(page_number)
	shows1 = list(pages)[:4]
	shows2 = list(pages)[4:]

	categories = ["Aucune","Boisson","Déssert","Féculent","Fruit de Mer","Légumes","Patisserie","Viande"]
	cates = list()
	class Cate:
		def __init__(self,cat):
			self.index = categories[cat]
			self.foods = Recette.objects.filter(m_category=cat)
			self.paginator = Paginator(self.foods,8)
			self.page_number = request.GET.get('page')
			self.page_foods = self.paginator.get_page(self.page_number)
	for i in range(1,len(categories)):
		cates.append(Cate(i))


	context = {	
		"banners":list(banners),
		"banner":banners[0],
		"banners2":banners2,
		"recettes":recettes,

		"shows1":shows1,
		"shows2":shows2,

		"categories":cates,
		"paginator":paginator,
		"num_pages":paginator.num_pages,
		'page_range':paginator.page_range,
		"pages":pages
	}
	
	
	try:
		purchases = request.session['purchases']
		if purchases in ["None",None,""]:
			context["nb_purchases"] = 0
		else:
			context["nb_purchases"] = len(purchases)
	except:
		request.session['purchases'] = []
		purchases = []
	context["nb_purchases"] = len(purchases)
	response = render(request,template,context)
	return response	

def foods(request,cat_val=0,specia_id=0,tri_val='',tri_ord='',my_r=0):
	template = "food/foods.html"
	specias = Meal.objects.filter()[:7]
	tendances = None
	new_foods = None
	some_recs = list()
	other_champs = True
	# Catalyseurs Tchopiques
	message1 = None
	message2 = ""
	if specia_id != 0:
		DB_RECETTES = Recette.objects.filter(m_meal__id = specia_id)
		meal = Meal.objects.get(id=specia_id)
		message1 = meal.m_name 
		message2 = meal.m_name_plus
		other_champs = False
	else:
		DB_RECETTES = Recette.objects.filter()
	if cat_val != 0:
		DB_RECETTES = DB_RECETTES.filter(m_category=cat_val)
	# Catalyseurs Tchopiques

	foods = DB_RECETTES.order_by('m_name')
	if other_champs:
		tendances = DB_RECETTES.order_by('m_stars')[:3]
		new_foods = DB_RECETTES.filter().order_by('-m_date_added')[:5]

	if tri_val != '':
		if tri_val == 'n':
			foods = foods.order_by('m_name')
		elif tri_val == 'r':
			foods = foods.order_by('m_date_added')
		elif tri_val == 'q':
			foods = foods.order_by('m_stars')
		elif tri_val == 'd':
			foods = foods.order_by('m_difficulty')
		elif tri_val == 'p':
			pass
	paginator = Paginator(foods,12)
	page_number = request.GET.get('page')
	page_foods = paginator.get_page(page_number)
	context = {
		'food':"Recettes disponibles",
		'tri_val':tri_val,
		'message1':message1,
		'message2':message2,
		'pages':page_foods,
		'num_pages':paginator.num_pages,
		'page_range':paginator.page_range,
		'link':1,
		'specias':specias,
		'new_foods':new_foods,
		'tendances':tendances,
	}
	context.update(basis(request))
	return render(request,template,context)

def food_modal_view(request,name,food):
	return foods_id(request,food,name)

def foods_id(request,food_id=1,name=None):
	template = "food/foods_detail.html"
	food = Recette.objects.get(id=food_id)
	if food.m_dariq == 1:
		FDQ = FoodDariq.objects.filter(m_food__id=food_id,m_user_token=int(request.COOKIES.get('id_token'))).count()	
		if FDQ > 0:
			template = "food/foods_detail.html"
		else:
			template = "food/YOU_LOG_food.html"
	specias = Meal.objects.filter()[:7]
	tendances = list()
	DB_RECETTES = Recette.objects.filter()
	foods = DB_RECETTES.order_by('m_name')
	for rec in DB_RECETTES.filter(m_stars=6)[:3]:
		tendances.append(rec)
	for rec in DB_RECETTES.exclude(m_stars=6)[:5]:#.order_by(m_stars)
		tendances.append(rec)
	
	new_foods = DB_RECETTES.filter().order_by('-m_date_added')[:12]
	context = {
		'specias':specias,
		'link':1,
		'food':food,
		'new_foods':new_foods,
		'tendances':tendances[:5]
	}
	context.update(basis(request))
	response = render(request,template,context)
	if name != None:
		response.set_cookie('firstname_token',name)
		context['comment'] = True
	return response

def specias(request):
	template = "food/specias.html"
	specias = Meal.objects.filter()
	best_sp = Meal.objects.filter()[:8]
	tendances = list()
	some_recs = list()
	for rec in Recette.objects.filter(m_stars=6)[:3]:
		tendances.append(rec)
	for rec in Recette.objects.exclude(m_stars=6)[:5]:#.order_by(m_stars)
		tendances.append(rec)
	paginator = Paginator(specias,12)
	page_number = request.GET.get('page')
	page_specias = paginator.get_page(page_number)
	context = {
		'link':2,
		'pages':page_specias,
		'num_pages':paginator.num_pages,
		'page_range':paginator.page_range,
		'specias':best_sp
	}
	context.update(basis(request))
	return render(request,template,context)

def cuistos(request):
	template = "food/cuistos.html"
	cuistos = Cooker.objects.filter()[:4]
	foods = Recette.objects.filter().order_by('m_name')
	new_foods = Recette.objects.filter().order_by('-m_date_added')[:12]
	paginator = Paginator(cuistos,12)
	page_number = request.GET.get('page')
	page_cuistos = paginator.get_page(page_number)
	context = {
		'pages':page_cuistos,
		'num_pages':paginator.num_pages,
		'page_range':paginator.page_range,
		'link':4,
		'cuistos':cuistos,
	}
	context.update(basis(request))
	return render(request,template,context)

def cuisto_id(request,cuisto_id):
	template = "food/cuisto_detail.html"
	cuisto = Cooker.objects.get(id=cuisto_id)
	foods = Recette.objects.filter()
	paginator = Paginator(foods,12)
	page_number = request.GET.get('page')
	page_foods = paginator.get_page(page_number)
	context = {
		'link':4,
		'cuisto':cuisto,
		'pages':page_foods,
		'num_pages':paginator.num_pages,
		'page_range':paginator.page_range,
	}
	context.update(basis(request))
	return render(request,template,context)

def specia_id(request,specia_id):
	template = "food/specia_id.html"
	specia = Meal.objects.get(id=specia_id)
	foods = Food.objects.filter(m_meal = specia)
	context ={

	}
	context.update(basis(request))
	return render(request,template,context)

def contact(request):
	template = "food/contact.html"
	context = {
		'link':5,
	}
	context.update(basis(request))
	return render(request,template,context)

def ajax_cat(request):
	data = {}
	cat = int(request.GET.get('cat','0'))
	if cat != 0:
		foods = Recette.objects.filter(m_category=cat)[:5]
	else:
		foods = Recette.objects.filter()[:5]
	foods_name = list()
	foods_desc = list()
	foods_id = list()
	foods_img = list()
	foods_stars = list()
	for f in foods:
		foods_name.append(f.m_name)
		foods_desc.append(f.m_description)
		foods_id.append(f.id)
		foods_img.append(f.m_picture.url)
		foods_stars.append(f.m_stars)
	data = {
		'foods_name':foods_name,
		'foods_desc':foods_desc,
		'foods_id':foods_id,
		'foods_img':foods_img,
		'foods_stars':foods_stars
	}
	return JsonResponse(data)

def ajax_comment(request):
	food_id = int(request.GET.get('food_id','0'))
	comments = Commentaire.objects.filter(m_recette__id = food_id)
	comms_name = list()
	comms_date = list()
	comms_mess = list()
	comms_img = list()
	comms_reply = list()
	for c in comments:
		comms_name.append(c.m_name)
		comms_date.append(c.m_date)
		comms_mess.append(c.m_message)
		#comms_img.append()
		comms_reply.append(c.m_reply)
	data = {
		'comms_name':comms_name,
		'comms_date':comms_date,
		'comms_mess':comms_mess,
		'comms_img':comms_img,
		'comms_reply':comms_reply,
		'foods_count':comments.count()
	}
	return JsonResponse(data)

def xerxes_abc(request):
	user = redirect('http://127.0.0.1:8002/json_rep/')
	return redirect('http://127.0.0.1:8002/json_rep/')

def xerxeslog(request):
	mail = request.POST['email']
	password = request.POST['password']
	user = User.objects.filter(email=mail).first()
	if user != None:
		user_login = authenticate(username = user.username,password = password)
		if user_login:
			login(request,user,backend='django.contrib.auth.backends.ModelBackend')
	response = redirect('/foodrecipes/')
	"""
	id_token = request.POST['id_token']
	firstname_token = request.POST['firstname_token']
	lastname_token = request.POST['lastname_token']
	color_token = request.POST['color_token']
	#response.set_cookie('visits', visits + 1 )
	response = redirect('/')
	response.set_cookie('id_token',str(id_token))
	response.set_cookie('firstname_token',str(firstname_token))
	response.set_cookie('lastname_token',str(lastname_token))
	response.set_cookie('username_token',str(firstname_token[0]))
	response.set_cookie('color_token',str(color_token))
	"""
	return response

def xerxestoken(request):
	email = request.POST['email']
	password = request.POST['password']
	file_test = open('../Xerxes/xerxes/user.txt','w')
	file_test.write(email+"|"+password)
	return redirect('http://xerxes.cm/log_ext/XerxesFood/food/food.xerxes.cm/')

def log_ext(request):
	# User Token get Informations
	file_test = open('./food/user.txt','r')
	line = file_test.read().split('|')
	response = redirect('/foodrecipes/')
	try:
		id_token = line[0]
		firstname_token = line[2]
		lastname_token = line[3]
		color_token = line[4]
		dariq_token = line[5]
		response.set_cookie('id_token',str(id_token))
		response.set_cookie('firstname_token',str(firstname_token))
		response.set_cookie('lastname_token',str(lastname_token))
		response.set_cookie('username_token',str(firstname_token[0]))
		response.set_cookie('color_token',str(color_token))
		response.set_cookie('dariq_token',str(dariq_token))	
	except :
		pass
	if os.path.exists("./food/user.txt"):
	  os.remove("./food/user.txt")
	return response

def log_out(request):
	response = redirect('/foodrecipes/')
	response.set_cookie('id_token','0')
	response.set_cookie('firstname_token','0')
	response.set_cookie('lastname_token','0')
	response.set_cookie('username_token','0')
	response.set_cookie('color_token','0')
	return response

def send_comm(request):
	is_reply = int(request.GET.get('reply'))
	value_id = int(request.GET.get('value_id'))
	user_token = Commentaire.objects.count()+1
	comment_val = request.GET.get('m_comment')
	name_token = request.COOKIES.get('firstname_token')
	comment = Commentaire(m_author=name_token,m_reply=is_reply,m_value_id=value_id,m_user_token=user_token,m_message=comment_val)
	comment.save()
	data = {

	}
	return JsonResponse(data,safe=False)

def load_comm(request):
	value = int(request.GET.get('value_id'))
	rang = int(request.GET.get('range'))
	comm_names = list()
	comm_vals = list()
	comm_dates = list()
	comm_ids = list()
	nb_repq = list()
	for c in Commentaire.objects.filter(m_value_id=value,m_reply=0)[rang*20:(rang+1)*20]:
		comm_names.append(c.m_author)
		comm_vals.append(c.m_message)
		comm_dates.append(str(c.m_date.ctime()))
		comm_ids.append(c.id)
		nb_repq.append(c.nb_rep())
	data = {
		'comm_names':comm_names,
		'comm_vals':comm_vals,
		'comm_dates':comm_dates,
		'comm_ids':comm_ids,
		'nb_rep':nb_repq
	}
	return JsonResponse(data,safe=False)

def send_like_result(request):
	r = Recette.objects.get(id=int(request.GET.get('value_id')))
	u_t = int(request.GET.get('user_token'))
	sens = int(request.GET.get('sens'))
	description = request.GET.get('description',None)
	try:
		RecetteDetail.objects.get(m_recette=r,m_user_token=u_t,m_sens=sens)
	except:
		rD = RecetteDetail(m_recette=r,m_user_token=u_t,m_sens=sens,m_description=description)
		rD.save()
	data = {
	}
	response = JsonResponse(data,safe=False)
	if u_t == 0:
		import random
		code = ""
	for i in range(7):
		code += str(random.randint(0,9))
		response.set_cookie('user_token',int(code))
	return response

def proposal(request):
	if request.user.is_authenticated:
		template = "food/proposal.html"
	else:
		template = "food/YOU_LOG.html"
	specialites = Meal.objects.filter()
	ingredients = Ingredient.objects.filter()
	context = {
		'specialites':specialites,
		'ingredients':ingredients
	}
	context.update(basis(request))
	return render(request,template,context)

def get_elt(request):
	value_ing = request.GET.get('value')
	data = {
		'result':0
	}
	try:
		value_ing = int(value_ing)
		if value_ing > 0:
			ing = Ingredient.objects.get(id=int(value_ing))
			data['picture'] = ing.m_picture.url
			data['result'] = 1
	except:
		data['result'] = 0
	return JsonResponse(data,safe=False)

def recette_form(request):	
	recette_link = request.POST['rec_link']
	recette_name = request.POST['rec_name']
	recette_image = request.FILES['rec_pic']
	recette_categorie = request.POST['rec_cat']
	rec_desc = request.POST['rec_desc']
	brouillon = request.POST['brouillon']
	
	if 'embed' not in recette_link:
		print(recette_link)
		if 'watch' not in recette_link:
			print("Mouf !")
			tmp_link = recette_link.split("/")
			re_link = 'https://youtube.com/embed/' + tmp_link[-1] + '/'
			recette_link = re_link
		else:
			recette_link = recette_link.replace("watch?v=","embed/")
	if request.POST['rec_specia'] not in [None,'0']:
		recette_specia = Meal.objects.get(id=int(request.POST['rec_specia']))
	else:
		recette_specia = None
	if recette_categorie not in [None,'0']:
		recette_cat = recette_categorie
	else:
		recette_cat = None

	if request.POST['rec_number'] != '':
		recette_number = request.POST['rec_number']
	else:
		recette_number = None
	if request.POST['time_start'] != '':
		time_start = int(request.POST['time_start'])
	else:
		time_start = None
	if request.POST['time_end'] != '':
		time_end = int(request.POST['time_end'])
	else:
		time_end = None
	recette_dariq = request.POST['recette_dariq']
	recette_difficulty = request.POST['rec_difficulty']
	recette_steps = request.POST['steps_food']
	recette_ings = request.POST['ings_food']
	recette_ingredients = list()
	if brouillon == '0':
		p = Proposal(m_name=recette_name,m_picture=recette_image,m_category=recette_categorie,m_meal=recette_specia,m_required_num=recette_number,m_difficulty = recette_difficulty,m_description=recette_steps)
		p.ingredients_list = recette_ings
	else:
		p = Recette(m_name=recette_name,m_picture=recette_image,m_category=recette_categorie,m_meal=recette_specia,m_required_num=recette_number,m_difficulty = recette_difficulty,m_description=recette_steps)
		#ing_result += id_ing+"|"+qte+"|"+unite;
		ingredients_steps = recette_ings.split("\n")
		for line in ingredients_steps[:-1]:
			tmp_ingredients = line.split("|")
			if tmp_ingredients[0] != '':
				ingredient = Ingredient.objects.get(id=int(tmp_ingredients[0]))
				recette_ingredients.append(IngredientRecette(m_quantite=tmp_ingredients[1],m_ingredient=ingredient,m_unite=tmp_ingredients[2]))
	p.m_description = rec_desc
	p.m_youtube_link = recette_link
	p.m_content = recette_steps
	p.m_preparation = time_start
	p.m_cuisson = time_end
	p.m_token = request.user
	p.m_recette_dariq = recette_dariq
	p.m_category = recette_cat
	p.m_meal = recette_specia
	p.save()
	for r in recette_ingredients:
		r.m_recette = p
		r.save()
	response = redirect('/foodrecipes/foods/'+str(p.id)+'/')
	#request.session['just_set'] = '1'
	# cookie just_add set
	return response
	#c = Cuisto(m_token = int(request.POST['user']),m_photo="")

def ajax_dq(request):
	#request.session["purchases"] = list()
	nature = int(request.GET.get("nature"))
	data = {"names":list(),"ids":list(),"imgs":list(),"prix":list(), "nbs":list()}
	if nature == 0:
		prds = request.session["purchases"]
		for p in prds:
			#data["names"].append(str(p))
			rec = Recette.objects.get(id=int(p["item_id"]))
			data["names"].append(rec.m_name)
			data["imgs"].append(rec.m_picture.url)
			data["ids"].append(rec.id)
			data["nbs"].append(str(p["qte_elt"]))
			data["prix"].append(str(rec.m_dariq))
	elif nature == 5:
		prds = request.session["purchases"]
		id_elt = int(request.GET.get("id_elt"))
		request.session["purchases"] = list()
		for p in prds:
			rec = Recette.objects.get(id=int(p["item_id"]))
			if int(p["item_id"]) != id_elt:
				request.session["purchases"].append(p)
	return JsonResponse(data,safe=False)

def get_stats(request):
	cookie_user = int(request.COOKIES.get('id_token')) 
	c = Cooker.objects.filter(m_token=cookie_user).first()
	propo_numb = 0
	if c != None:
		propo_numb = c.nb_recettes()
	rds = RecetteDetail.objects.filter(m_user_token=cookie_user)
	master_numb = rds.filter(m_sens=0).count()
	diff_numb = rds.filter(m_sens=1).count()
	data = {
		'propo_numb':propo_numb,
		'master_numb':master_numb,
		'diff_numb':diff_numb
	}
	return JsonResponse(data,safe=False)

def myfoods(request):
	template = "food/my_foods.html"
	fdq = FoodDariq.objects.filter(m_user_token=int(request.COOKIES.get('id_token'))) 
	recettes = list()
	for f in fdq:
		recettes.append(f.m_food)
	context = {
		'recettes':recettes
	}
	context.update(basis(request))
	return render(request,template,context)

def save_cooks(request):
	name = request.POST['name']
	mail = request.POST['mail']
	food = request.POST['food']
	response = "/foods/"+food+"/"
	response.set_cookie('firstname_token',name)
	return response

def ajax_foods(request):
	list_ids = [int(s) for s in request.GET.get("ids").split("#")[:-1]]
	#int(request.GET.get('value_id'))
	#rang = int(request.GET.get('range'))
	foods = Recette.objects.filterr(id__in=list_ids)

	food_names = list()
	food_imgs = list()
	food_descriptions = list()
	food_ids = list()
	for f in foods:
		food_ids.append(str(f.id))
		food_names.append(str(f.m_name))
		food_imgs.append(f.m_picture.url)
		food_descriptions.append(f.m_description)
	data = {
		'food_ids':food_ids,
		'food_names':food_names,
		'food_imgs':food_imgs,
		'food_descriptions':food_descriptions
	}
	return JsonResponse(data,safe=False)

def cookie_token(request):
	purchases = request.session['purchases']
	is_there = False
	id_elt = request.GET.get("id_elt")
	qte_elt = request.GET.get("qte_elt")
	for p in purchases:
		if id_elt == p["item_id"]:
			p["qte_elt"] = qte_elt
			is_there = True
			break
	if is_there == False:
		purchases.append({"item_id":request.GET.get("id_elt"),"qte_elt":request.GET.get("qte_elt")})
	request.session['purchases'] = purchases
	#purchases
	#response.set_cookie('purchases',name)
	data = {
		"nb_purchases":len(request.session['purchases'])
	}
	return JsonResponse(data,safe=False)